package com.jeethink.save.service.impl;

import java.util.List;
import com.jeethink.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.jeethink.save.mapper.archiveHandOverMapper;
import com.jeethink.bean.domain.ArchivesMaster;
import com.jeethink.save.service.IarchiveHandOverService;

/**
 * 档案移交Service业务层处理
 * 
 * @author sh
 * @date 2022-11-11
 */
@Service
public class archiveHandOverServiceImpl implements IarchiveHandOverService 
{
    @Autowired
    private archiveHandOverMapper archiveHandOverMapper;

    /**
     * 查询档案移交
     * 
     * @param archivesId 档案移交ID
     * @return 档案移交
     */
    @Override
    public ArchivesMaster selectarchiveHandOverById(String archivesId)
    {
        return archiveHandOverMapper.selectarchiveHandOverById(archivesId);
    }

    /**
     * 查询档案移交列表
     * 
     * @param archiveHandOver 档案移交
     * @return 档案移交
     */
    @Override
    public List<ArchivesMaster> selectarchiveHandOverList(ArchivesMaster archiveHandOver)
    {
        return archiveHandOverMapper.selectarchiveHandOverList(archiveHandOver);
    }

    /**
     * 新增档案移交
     * 
     * @param archiveHandOver 档案移交
     * @return 结果
     */
    @Override
    public int insertarchiveHandOver(ArchivesMaster archiveHandOver)
    {
        archiveHandOver.setCreateTime(DateUtils.getNowDate());
        return archiveHandOverMapper.insertarchiveHandOver(archiveHandOver);
    }

    /**
     * 修改档案移交
     * 
     * @param archiveHandOver 档案移交
     * @return 结果
     */
    @Override
    public int updatearchiveHandOver(ArchivesMaster archiveHandOver)
    {
        archiveHandOver.setUpdateTime(DateUtils.getNowDate());
        return archiveHandOverMapper.updatearchiveHandOver(archiveHandOver);
    }

    /**
     * 批量删除档案移交
     * 
     * @param archivesIds 需要删除的档案移交ID
     * @return 结果
     */
    @Override
    public int deletearchiveHandOverByIds(String[] archivesIds)
    {
        return archiveHandOverMapper.deletearchiveHandOverByIds(archivesIds);
    }

    /**
     * 删除档案移交信息
     * 
     * @param archivesId 档案移交ID
     * @return 结果
     */
    @Override
    public int deletearchiveHandOverById(String archivesId)
    {
        return archiveHandOverMapper.deletearchiveHandOverById(archivesId);
    }
}
